"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const helper_1 = require("./helper");
const typescript_ilogger_1 = require("typescript-ilogger");
const test_values_1 = require("./test-values");
const decryptResponseResponse = {};
const encryptResponseResponse = {};
const decrypt = jest.fn().mockImplementation(() => {
    return Promise.resolve(decryptResponseResponse);
});
const encrypt = jest.fn().mockImplementation(() => {
    return Promise.resolve(encryptResponseResponse);
});
jest.mock('@aws-sdk/client-kms', () => {
    return {
        KMS: jest.fn().mockImplementation(() => {
            return {
                decrypt,
                encrypt,
            };
        }),
    };
});
const logger = new typescript_ilogger_1.Logger(typescript_ilogger_1.LogLevel.Off);
const kmsHelperMock = new helper_1.KMSHelper(logger);
const TestValues = new test_values_1.TestingValues();
describe(`${helper_1.KMSHelper.name}.${kmsHelperMock.DecryptAsync.name}`, () => {
    const action = `${helper_1.KMSHelper.name}.${kmsHelperMock.DecryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} encryptedValue`, () => {
        const actual = kmsHelperMock.DecryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} encryptedValue`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = kmsHelperMock.DecryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(decryptResponseResponse);
    });
});
describe(`${helper_1.KMSHelper.name}.${kmsHelperMock.EncryptAsync.name}`, () => {
    const action = `${helper_1.KMSHelper.name}.${kmsHelperMock.EncryptAsync.name}`;
    test(`${TestValues.ThrowsOnEmpty} unencryptedValue`, () => {
        const actual = kmsHelperMock.EncryptAsync(TestValues.EmptyString);
        return expect(actual).rejects.toThrow(`[${action}]-${TestValues.MustSupply} unencryptedValue`);
    });
    test(`${TestValues.ValidTest}`, () => {
        const actual = kmsHelperMock.EncryptAsync(TestValues.StringValue);
        return expect(actual).resolves.toEqual(encryptResponseResponse);
    });
});
//# sourceMappingURL=helper-resolves.spec.js.map