"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KMSHelper = void 0;
const KMS = require("@aws-sdk/client-kms");
const uuid_1 = require("uuid");
const typescript_helper_functions_1 = require("typescript-helper-functions");
class KMSHelper extends typescript_helper_functions_1.BaseClass {
    Repository;
    constructor(logger, repository, options) {
        super(logger);
        options = this.ObjectOperations.IsNullOrEmpty(options)
            ? { region: 'us-east-1' }
            :
                options;
        this.Repository = repository || new KMS.KMS(options);
    }
    async DecryptAsync(encryptedValue) {
        const action = `${KMSHelper.name}.${this.DecryptAsync.name}`;
        this.LogHelper.LogInputs(action, { cipherTextBlob: encryptedValue });
        if (this.ObjectOperations.IsNullOrWhitespace(encryptedValue)) {
            throw new Error(`[${action}]-Must supply encryptedValue`);
        }
        const array = this.ObjectOperations.ConvertStringToArrayBuffer(encryptedValue);
        const params = {
            CiphertextBlob: array,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.decrypt(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
    async EncryptAsync(unencryptedValue) {
        const action = `${KMSHelper.name}.${this.EncryptAsync.name}`;
        this.LogHelper.LogInputs(action, { cipherTextBlob: unencryptedValue });
        if (this.ObjectOperations.IsNullOrWhitespace(unencryptedValue)) {
            throw new Error(`[${action}]-Must supply unencryptedValue`);
        }
        const array = this.ObjectOperations.ConvertStringToArrayBuffer(unencryptedValue);
        const params = {
            KeyId: (0, uuid_1.v4)(),
            Plaintext: array,
        };
        this.LogHelper.LogRequest(action, params);
        const response = await this.Repository.encrypt(params);
        this.LogHelper.LogResponse(action, response);
        return response;
    }
}
exports.KMSHelper = KMSHelper;
//# sourceMappingURL=helper.js.map